# selenium_cookies

![PyPI - package version](https://img.shields.io/pypi/v/selenium_cookies?logo=pypi&style=flat-square)
![PyPI - license](https://img.shields.io/pypi/l/selenium_cookies?label=package%20license&style=flat-square)
![PyPI - python version](https://img.shields.io/pypi/pyversions/selenium_cookies?logo=pypi&style=flat-square)
![PyPI - downloads](https://img.shields.io/pypi/dm/selenium_cookies?logo=pypi&style=flat-square)

![GitHub - last commit](https://img.shields.io/github/last-commit/kkristof200/selenium_cookies?style=flat-square)
![GitHub - commit activity](https://img.shields.io/github/commit-activity/m/kkristof200/selenium_cookies?style=flat-square)

![GitHub - code size in bytes](https://img.shields.io/github/languages/code-size/kkristof200/selenium_cookies?style=flat-square)
![GitHub - repo size](https://img.shields.io/github/repo-size/kkristof200/selenium_cookies?style=flat-square)
![GitHub - lines of code](https://img.shields.io/tokei/lines/github/kkristof200/selenium_cookies?style=flat-square)

![GitHub - license](https://img.shields.io/github/license/kkristof200/selenium_cookies?label=repo%20license&style=flat-square)

## Description



## Install

~~~~bash
pip install selenium_cookies
# or
pip3 install selenium_cookies
~~~~

## Usage

~~~~python
import selenium_cookies
~~~~

## Dependencies

[tldextract](https://pypi.org/project/tldextract)